
Mixed-Up Code Questions
-----------------------

.. selectquestion:: Inheritance_MixedUpCode_1_sq_v3
   :fromid: inheritance_mixed1_v3, inheritance_mixed1_ac_v3
   :toggle:


.. selectquestion:: Inheritance_MixedUpCode_2_sq_v3
   :fromid: inheritance_mixed2_v3, inheritance_mixed2_ac_v3
   :toggle:


.. selectquestion:: Inheritance_MixedUpCode_3_sq_v3
   :fromid: inheritance_mixed3_v3, inheritance_mixed3_ac_v3
   :toggle:


.. selectquestion:: Inheritance_MixedUpCode_4_sq_v3
   :fromid: inheritance_mixed4_v3, inheritance_mixed4_ac_v3
   :toggle:


.. selectquestion:: Inheritance_MixedUpCode_5_sq_v3
   :fromid: inheritance_mixed5_v3, inheritance_mixed5_ac_v3
   :toggle:


.. selectquestion:: Inheritance_MixedUpCode_6_sq_v3
   :fromid: inheritance_mixed6_v3, inheritance_mixed6_ac_v3
   :toggle:


.. selectquestion:: Inheritance_MixedUpCode_7_sq_v3
   :fromid: inheritance_mixed7_v3, inheritance_mixed7_ac_v3
   :toggle:


.. selectquestion:: Inheritance_MixedUpCode_8_sq_v3
   :fromid: inheritance_mixed8_v3, inheritance_mixed8_ac_v3
   :toggle:


.. selectquestion:: Inheritance_MixedUpCode_9_sq_v3
   :fromid: inheritance_mixed9_v3, inheritance_mixed9_ac_v3
   :toggle:


.. selectquestion:: Inheritance_MixedUpCode_10_sq_v3
   :fromid: inheritance_mixed10_v3, inheritance_mixed10_ac_v3
   :toggle:
